@@ -13,10 +13,10 @@ from omnitools import dt2yyyymmddhhmmss, ApacheHeadersDict, str2html
 
 
 _SERVER = dict(os.environ)
-for k in _SERVER.keys():
+for k in list(_SERVER.keys()):
     if k.startswith("REDIRECT_"):
         _SERVER[k.replace("REDIRECT_", "")] = _SERVER[k]
-arguments = FieldStorage(environ=os.environ)
+arguments = FieldStorage(environ=_SERVER)
 arguments = {k: [_.value for _ in arguments[k]] if isinstance(arguments[k], list) else arguments[k].value for k in arguments}
 _GET = arguments
 _POST = arguments
